#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: semigroupoids
version: 5.0.1
id: semigroupoids-5.0.1-b7bab91a6942fe7ff71ed4cef8e5d2c6
key: semig_2le8O5tVFT71d48XScu2SK
license: BSD3
copyright: Copyright (C) 2011-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/semigroupoids
synopsis: Semigroupoids: Category sans id
description:
    Provides a wide array of (semi)groupoids and operations for working with them.
    .
    A '\''Semigroupoid'\'' is a '\''Category'\'' without the requirement of identity arrows for every object in the category.
    .
    A '\''Category'\'' is any '\''Semigroupoid'\'' for which the Yoneda lemma holds.
    .
    When working with comonads you often have the @\<*\>@ portion of an @Applicative@, but
    not the @pure@. This was captured in Uustalu and Vene'\''s \"Essence of Dataflow Programming\"
    in the form of the @ComonadZip@ class in the days before @Applicative@. Apply provides a weaker invariant, but for the comonads used for data flow programming (found in the streams package), this invariant is preserved. Applicative function composition forms a semigroupoid.
    .
    Similarly many structures are nearly a comonad, but not quite, for instance lists provide a reasonable '\''extend'\'' operation in the form of '\''tails'\'', but do not always contain a value.
    .
    Ideally the following relationships would hold:
    .
    > Foldable ----> Traversable <--- Functor ------> Alt ---------> Plus           Semigroupoid
    >      |               |            |                              |                  |
    >      v               v            v                              v                  v
    > Foldable1 ---> Traversable1     Apply --------> Applicative -> Alternative      Category
    >                                   |               |              |                  |
    >                                   v               v              v                  v
    >                                 Bind ---------> Monad -------> MonadPlus          Arrow
    >
    .
    Apply, Bind, and Extend (not shown) give rise the Static, Kleisli and Cokleisli semigroupoids respectively.
    .
    This lets us remove many of the restrictions from various monad transformers
    as in many cases the binding operation or @\<*\>@ operation does not require them.
    .
    Finally, to work with these weaker structures it is beneficial to have containers
    that can provide stronger guarantees about their contents, so versions of '\''Traversable'\''
    and '\''Foldable'\'' that can be folded with just a '\''Semigroup'\'' are added.
category: Control, Comonads
author: Edward A. Kmett
exposed: True
exposed-modules:
    Data.Bifunctor.Apply Data.Functor.Alt Data.Functor.Apply
    Data.Functor.Bind Data.Functor.Bind.Class Data.Functor.Bind.Trans
    Data.Functor.Extend Data.Functor.Plus Data.Groupoid
    Data.Isomorphism Data.Semigroup.Bifoldable
    Data.Semigroup.Bitraversable Data.Semigroup.Foldable
    Data.Semigroup.Foldable.Class Data.Semigroup.Traversable
    Data.Semigroup.Traversable.Class Data.Semigroupoid
    Data.Semigroupoid.Dual Data.Semigroupoid.Ob
    Data.Semigroupoid.Static Data.Traversable.Instances
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/semigroupoids-5.0.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/semigroupoids-5.0.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/semigroupoids-5.0.1
hs-libraries: HSsemigroupoids-5.0.1-2le8O5tVFT71d48XScu2SK
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    base-orphans-0.5.0-a13c08e02979420be3bfcfc755842cf4
    bifunctors-5.2-0441742d378c12894f2416d3db8487ca
    comonad-5-8a962074b8e5e5443dcfbe8fc3ec8e2a
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    contravariant-1.4-b111d3a1a4df36292e7fa2721a750043
    distributive-0.5.0.2-4adc293a164a7098de193ed7fd4fb4a3
    semigroups-0.18.0.1-09717ed0a84e1dbeffebbb54d604d271
    tagged-0.8.2-849e3b2865ae1877e32ec9d4d01c3d0a
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    transformers-compat-0.4.0.4-8aa4073730c676dbe210ea8bffd8d092
haddock-interfaces: /usr/share/doc/haskell-semigroupoids/html/semigroupoids.haddock
haddock-html: /usr/share/doc/haskell-semigroupoids/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
